# Sodium

Port of Sodium - Functional Reactive Programming (FRP) library - to Python.

## Installation

Just `pip install sodiumfrp`.

## Documentation

The most comprehensive guide on this library would be the book
[Functional Reactive Programming by Stephen Blackheath](https://www.manning.com/books/functional-reactive-programming).
Even though, the book aims Java, it is pretty straightforward to map it into Python.

To build [API reference](https://sodium-python.readthedocs.io), go to `docs` directory and run `make html`.
It requires `sphinx` and `sphinx-rtd-theme` packages to be installed.

## Examples

See [examples](examples) directory.

## Development

To run the tests, execute `pytest` from the package directory.

## License

Distributed under [BSD 3-Clause](https://github.com/SodiumFRP/sodium/blob/master/COPYING).
